diff -ru a/src/video_output/video_output.c b/src/video_output/video_output.c
--- a/src/video_output/video_output.c	2008-11-05 00:11:09.000000000 +0100
+++ b/src/video_output/video_output.c	2008-11-12 16:29:10.000000000 +0100
@@ -114,6 +114,8 @@
 #   define VOUT_MIN_DIRECT_PICTURES        (3*VOUT_MAX_PICTURES/4)
 #endif
 
+static int vout_reinit_vout( vout_thread_t* p_vout, video_format_t *p_fmt );
+
 /*****************************************************************************
  * Video Filter2 functions
  *****************************************************************************/
@@ -160,7 +162,13 @@
          * TODO: support for reusing video outputs with proper _thread-safe_
          * reference handling. */
         if( p_vout )
-            vout_CloseAndRelease( p_vout );
+        {
+            vlc_object_detach ( p_vout );
+            vlc_object_attach ( p_vout , p_vout->p_libvlc );
+            vlc_object_release( p_vout );
+            msg_Dbg( p_this, "vout saved for future use" );
+        }
+
         return NULL;
     }
 
@@ -281,6 +289,33 @@
         }
     }
 
+    if ( !p_vout )
+    {
+        p_vout = vlc_object_find( p_this->p_libvlc,
+                                  VLC_OBJECT_VOUT, FIND_CHILD );
+        if ( p_vout )
+        {
+            if ( p_vout->p_parent == p_vout->p_libvlc )
+            {
+                /**
+                 * This vout can be re-used  
+                 */
+                vlc_object_detach ( p_vout );
+                vlc_object_attach ( p_vout , p_this );
+                vout_reinit_vout ( p_vout, p_fmt );
+                msg_Dbg( p_this, "reusing vout ... " );
+            }
+            else
+            {
+                /**
+                 * Regular vout (already in hand, don't touch !)
+                 */
+                vlc_object_release( p_vout );
+                p_vout = NULL;
+            }
+        }
+    }
+
     if( !p_vout )
     {
         msg_Dbg( p_this, "no usable vout present, spawning one" );
@@ -1749,3 +1784,100 @@
     }
 }
 
+/*
+ * function implemented by reusing existing CleanThread and InitThread
+ */
+int vout_reinit_vout ( vout_thread_t* p_vout, video_format_t *p_fmt )
+{
+    vlc_mutex_lock( &p_vout->change_lock );
+    
+    /**
+     * CleanThread seems to be right to get rid of all previous data
+     */
+
+    CleanThread( p_vout );
+
+    /**
+     * Reset (almost) all as it was done the first time
+     */
+
+    unsigned int i_width = p_fmt->i_width;
+    unsigned int i_height = p_fmt->i_height;
+    vlc_fourcc_t i_chroma = p_fmt->i_chroma;
+    unsigned int i_aspect = p_fmt->i_aspect;
+
+    if( i_width <= 0 || i_height <= 0 || i_aspect <= 0 )
+        return NULL;
+
+    vlc_ureduce( &p_fmt->i_sar_num, &p_fmt->i_sar_den,
+                 p_fmt->i_sar_num, p_fmt->i_sar_den, 50000 );
+    if( p_fmt->i_sar_num <= 0 || p_fmt->i_sar_den <= 0 )
+        return NULL;
+
+    /* Initialize pictures - translation tables and functions
+     * will be initialized later in InitThread */
+    for( int i_index = 0; i_index < 2 * VOUT_MAX_PICTURES + 1; i_index++)
+    {
+//        p_vout->p_picture[i_index].pf_lock = NULL;
+//        p_vout->p_picture[i_index].pf_unlock = NULL;
+        p_vout->p_picture[i_index].i_status = FREE_PICTURE;
+        p_vout->p_picture[i_index].i_type   = EMPTY_PICTURE;
+        p_vout->p_picture[i_index].b_slow   = 0;
+    }
+
+    /* No images in the heap */
+    p_vout->i_heap_size = 0;
+
+    /* Initialize the rendering heap */
+    I_RENDERPICTURES = 0;
+
+    p_vout->fmt_render        = *p_fmt;   /* FIXME palette */
+    p_vout->fmt_in            = *p_fmt;   /* FIXME palette */
+
+    p_vout->render.i_width    = i_width;
+    p_vout->render.i_height   = i_height;
+    p_vout->render.i_chroma   = i_chroma;
+    p_vout->render.i_aspect   = i_aspect;
+
+    p_vout->render.i_rmask    = p_fmt->i_rmask;
+    p_vout->render.i_gmask    = p_fmt->i_gmask;
+    p_vout->render.i_bmask    = p_fmt->i_bmask;
+
+    p_vout->render.i_last_used_pic = -1;
+    p_vout->render.b_allow_modify_pics = 1;
+
+    /**
+     * Keep output parameters for a seamless transition
+     *  - width, height, chroma
+     */
+
+    //I_OUTPUTPICTURES = 0;
+    //p_vout->output.i_width    = 0;
+    //p_vout->output.i_height   = 0;
+    //p_vout->output.i_chroma   = 0;
+    //p_vout->output.i_aspect   = 0;
+
+    //p_vout->output.i_rmask    = 0;
+    //p_vout->output.i_gmask    = 0;
+    //p_vout->output.i_bmask    = 0;
+
+    /* Initialize misc stuff */
+    //p_vout->i_changes &= VOUT_ASPECT_CHANGE;
+    //p_vout->i_changes &= VOUT_SIZE_CHANGE;
+    
+    /**
+     * InitThread re-start everything 
+     */
+
+    InitThread( p_vout );
+
+    vlc_mutex_unlock( &p_vout->change_lock );
+
+    /**
+     * Last thing to do, get a proper aspect-ratio
+     * this call resets aspect-ratio to a predefined value
+     */
+
+    var_SetString(p_vout, "aspect-ratio", "");
+
+}
